@@ -10,7 +10,7 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 
-config etc/rc.d/rc.modules-2.6.7.new
+config etc/rc.d/rc.modules-2.6.10.new
 
 # If rc.modules is a real file, back it up:
 if [ -r etc/rc.d/rc.modules -a ! -L etc/rc.d/rc.modules ]; then
@@ -21,7 +21,7 @@ fi
 # of this script on your own...
 if [ ! -L etc/rc.d/rc.modules ]; then
   ( cd etc/rc.d ; rm -rf rc.modules )
-  ( cd etc/rc.d ; ln -sf rc.modules-2.6.7 rc.modules )
+  ( cd etc/rc.d ; ln -sf rc.modules-2.6.10 rc.modules )
 fi
 
 # A good idea whenever kernel modules are added or changed:
@@ -29,5 +29,7 @@ if [ -x sbin/depmod ]; then
   chroot . /sbin/depmod -a 1> /dev/null 2> /dev/null
 fi
 
-( cd lib/modules/2.6.7 ; rm -rf build )
-( cd lib/modules/2.6.7 ; ln -sf /usr/src/linux-2.6.7 build )
+( cd lib/modules/2.6.10 ; rm -rf build )
+( cd lib/modules/2.6.10 ; ln -sf /usr/src/linux-2.6.10 build )
+( cd lib/modules/2.6.10 ; rm -rf source )
+( cd lib/modules/2.6.10 ; ln -sf /usr/src/linux-2.6.10 source )
